==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/ExecActionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ExecActionFluent<A extends ExecActionFluent<A>> extends Fluent<A> {


    public A addToCommand(int index,String item);
    public A setToCommand(int index,String item);
    public A addToCommand(String... items);
    public A addAllToCommand(Collection<String> items);
    public A removeFromCommand(String... items);
    public A removeAllFromCommand(Collection<String> items);
    public List<String> getCommand();
    public String getCommand(int index);
    public String getFirstCommand();
    public String getLastCommand();
    public String getMatchingCommand(Predicate<String> predicate);
    public Boolean hasMatchingCommand(Predicate<String> predicate);
    public A withCommand(List<String> command);
    public A withCommand(String... command);
    public Boolean hasCommand();
    public A addNewCommand(StringBuilder arg1);
    public A addNewCommand(int[] arg1,int arg2,int arg3);
    public A addNewCommand(char[] arg1);
    public A addNewCommand(StringBuffer arg1);
    public A addNewCommand(byte[] arg1,int arg2);
    public A addNewCommand(byte[] arg1);
    public A addNewCommand(char[] arg1,int arg2,int arg3);
    public A addNewCommand(byte[] arg1,int arg2,int arg3);
    public A addNewCommand(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewCommand(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/ExecActionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ExecActionFluent<A extends ExecActionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToCommand(int index,String item);
    public A setToCommand(int index,String item);
    public A addToCommand(String... items);
    public A addAllToCommand(Collection<String> items);
    public A removeFromCommand(String... items);
    public A removeAllFromCommand(Collection<String> items);
    public List<String> getCommand();
    public String getCommand(int index);
    public String getFirstCommand();
    public String getLastCommand();
    public String getMatchingCommand(Predicate<String> predicate);
    public Boolean hasMatchingCommand(Predicate<String> predicate);
    public A withCommand(List<String> command);
    public A withCommand(String... command);
    public Boolean hasCommand();
    public A addNewCommand(StringBuilder arg1);
    public A addNewCommand(int[] arg1,int arg2,int arg3);
    public A addNewCommand(char[] arg1);
    public A addNewCommand(StringBuffer arg1);
    public A addNewCommand(byte[] arg1,int arg2);
    public A addNewCommand(byte[] arg1);
    public A addNewCommand(char[] arg1,int arg2,int arg3);
    public A addNewCommand(byte[] arg1,int arg2,int arg3);
    public A addNewCommand(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewCommand(String arg1);
}
